package HelloWorld;

import java.util.*;
import java.io.*;
import java.rmi.*;
import javax.ejb.*;


/**
 * The enterprise-bean class for a Session Enterprise Java Bean.
 * After generation, this class contains the required methods for bean compilation and
 * deployment, but no business logic.
 * The bean developer may add create and business methods here, matching the
 * corresponding methods in the remote or home interfaces.
 * A create method with no arguments is required for all session EJBs.
 */

public class HelloBean implements SessionBean 
{
    /**
     * Called by the container after creating this instance, and before transferring it to the pool of
     * available instances.  This is a good place to allocate resources which are scoped to the lifetime
     * of the instance.
     * @param ctx SessionContext the link between this bean and its container
     */
    public void setSessionContext(javax.ejb.SessionContext ctx)
    {
        m_ctx = ctx;
    }

    /**
      * The stateless session bean class (or a super-class) must define a single ejbCreate method that takes no arguments and returns void.
      * The stateless session bean class' ejbCreate method's signatures must follow these rules:
      * 
      *     The method name must be ejbCreate.
      *     The method must be declared as public.
      *     The method must not be declared as final or static.
      *     The return type must be void.
      *     There may not be any method arguments.
      *     The throws clause may define arbitrary application exceptions, possibly including the javax.ejb.CreateException.


      * Compatibility Note: EJB 1.0 allowed the ejbCreate method to throw the java.rmi.RemoteException
      * to indicate a non-application exception. This practice is deprecated in EJB 1.1 -- an EJB 1.1 
      * compliant enterprise bean should throw the javax.ejb.EJBException or another RuntimeException to
      * indicate non-application exceptions to the Container.
      */
    public void ejbCreate()
    {
    }


    /**
     * Called by the container when this instance is being destroyed due to a user remove()
     * operation, or after expiration of a timeout.
     */
    public void ejbRemove() 
    {
    }


    /**
     * Called when the instance is activated from its "passive" state. The instance should
     * acquire any resource that it has released earlier in the ejbPassivate() method.
     */
    public void ejbActivate() 
    {
    }


    /**
     * Called before the instance enters the "passive" state. The instance should release
     * any resources that it can re-acquire later in the ejbActivate() method.
     */
    public void ejbPassivate() 
    {
    }


    /**
     * Null constructor, mandatory for serialization/activation/passivation.
     */
    public HelloBean()
    {
    }

    public String Hello(String name) throws RemoteException {
	String message = null;
	java.util.Calendar cal = new GregorianCalendar();
	int currentHour = cal.get(Calendar.HOUR_OF_DAY);
	if (currentHour < 12) message = "morning";
	else{
	    if ((currentHour >= 12)&& (currentHour < 18)) message = "afternoon";
	    else message = "evening";
    }
        //return ("HelloBean says Good "+message+" " + name);
        return ("Good "+ message+", " + name +". Enjoy your  " + message +".");
	}

    /**
     * The session context is not serializable, and should be
     * cached in a transient member variable
     */
    private transient javax.ejb.SessionContext m_ctx = null;
}



